@@ -8,11 +8,18 @@
 #'
 #' @param year Election year. For this function, only the years 1998, 2002, 2006, 2010, and 2014
 #' are available.
+#' 
+#' @param uf Filter results by Federation Unit acronym (\code{character vector}).
 #'
 #' @param ascii (\code{logical}). Should the text be transformed from Latin-1 to ASCII format?
 #'
-#' @param encoding Data original encoding (defaults to 'windows-1252'). This can be changed to avoid errors
+#' @param encoding Data original encoding (defaults to 'Latin-1'). This can be changed to avoid errors
 #' when \code{ascii = TRUE}.
+#' 
+#' @param export (\code{logical}). Should the downloaded data be saved in .dta and .sav in the current directory?
+#'
+#' @details If export is set to \code{TRUE}, the downloaded data is saved as .dta and .sav
+#'  files in the current directory.
 #'
 #' @return \code{party_mun_zone_fed()} returns a \code{data.frame} with the following variables:
 #'
@@ -44,6 +51,8 @@
 #'   \item TRANSITO: It informs whether the record relates or not to absentee ballot votes (only for 2014 election).
 #' }
 #'
+#' @seealso \code{\link{party_mun_zone_local}} for local elections in Brazil.
+#'
 #' @import utils
 #' @importFrom magrittr "%>%"
 #' @export
@@ -52,12 +61,13 @@
 #' df <- party_mun_zone_fed(2002)
 #' }
 
-party_mun_zone_fed <- function(year, ascii = FALSE, encoding = "windows-1252"){
+party_mun_zone_fed <- function(year, uf = "all", ascii = FALSE, encoding = "Latin-1", export = FALSE){
 
 
   # Test the input
   test_encoding(encoding)
   test_fed_year(year)
+  uf <- test_uf(uf)
 
   # Download the data
   dados <- tempfile()
@@ -70,7 +80,7 @@ party_mun_zone_fed <- function(year, ascii = FALSE, encoding = "windows-1252"){
   
   # Cleans the data
   setwd(as.character(year))
-  banco <- juntaDados(encoding)
+  banco <- juntaDados(uf, encoding)
   setwd("..")
   unlink(as.character(year), recursive = T)
 
@@ -92,6 +102,9 @@ party_mun_zone_fed <- function(year, ascii = FALSE, encoding = "windows-1252"){
   
   # Change to ascii
   if(ascii == T) banco <- to_ascii(banco, encoding)
+  
+  # Export
+  if(export) export_data(banco)
 
   message("Done.\n")
   return(banco)
