@@ -9,10 +9,17 @@
 #' @param year Election year. For this function, only the years 1996, 2000, 2004, 2008, 2012, and 2016
 #' are available.
 #' 
+#' @param uf Federation Unit acronym (\code{character vector}).
+#' 
 #' @param ascii (\code{logical}). Should the text be transformed from Latin-1 to ASCII format?
 #'
-#' @param encoding Data original encoding (defaults to 'windows-1252'). This can be changed to avoid errors
+#' @param encoding Data original encoding (defaults to 'Latin-1'). This can be changed to avoid errors
 #' when \code{ascii = TRUE}.
+#' 
+#' @param export (\code{logical}). Should the downloaded data be saved in .dta and .sav in the current directory?
+#'
+#' @details If export is set to \code{TRUE}, the downloaded data is saved as .dta and .sav
+#'  files in the current directory.
 #'
 #' @return \code{party_mun_zone_local()} returns a \code{data.frame} with the following variables:
 #'
@@ -44,6 +51,8 @@
 #'   \item TRANSITO: Electoral result outside the candidates' district? (N for no).
 #' }
 #'
+#' @seealso \code{\link{party_mun_zone_fed}} for local federal in Brazil.
+#'
 #' @import utils
 #' @importFrom magrittr "%>%"
 #' @export
@@ -53,12 +62,13 @@
 #' }
 
 
-party_mun_zone_local <- function(year, ascii = FALSE, encoding = "windows-1252"){
+party_mun_zone_local <- function(year, uf = "all", ascii = FALSE, encoding = "Latin-1", export = FALSE){
 
 
   # Test the input
   test_encoding(encoding)
   test_local_year(year)
+  uf <- test_uf(uf)
 
   # Download the data
   dados <- tempfile()
@@ -72,7 +82,7 @@ party_mun_zone_local <- function(year, ascii = FALSE, encoding = "windows-1252")
 
   # Cleans the data
   setwd(as.character(year))
-  banco <- juntaDados(encoding)
+  banco <- juntaDados(uf, encoding)
   setwd("..")
   unlink(as.character(year), recursive = T)
 
@@ -89,12 +99,15 @@ party_mun_zone_local <- function(year, ascii = FALSE, encoding = "windows-1252")
                       "SIGLA_UF", "SIGLA_UE", "CODIGO_MUNICIPIO", "NOME_MUNICIPIO", "NUMERO_ZONA",
                       "CODIGO_CARGO", "DESCRICAO_CARGO", "TIPO_LEGENDA", "NOME_COLIGACAO", "COMPOSICAO_LEGENDA",
                       "SIGLA_PARTIDO", "NUMERO_PARTIDO", "NOME_PARTIDO", "QTDE_VOTOS_NOMINAIS",
-                      "QTDE_VOTOS_LEGENDA", "SEQUENCIAL_LEGENDA", "TRANSITO")
+                      "QTDE_VOTOS_LEGENDA", "TRANSITO", "SEQUENCIAL_LEGENDA")
   }
     
   # Change to ascii
   if(ascii == T) banco <- to_ascii(banco, encoding)
 
+  # Export
+  if(export) export_data(banco)
+  
   message("Done.\n")
   return(banco)
 }
