@@ -10,6 +10,11 @@
 #'
 #' @param encoding Data original encoding (defaults to 'windows-1252'). This can be changed to avoid errors
 #' when \code{ascii = TRUE}.
+#' 
+#' @param export (\code{logical}). Should the downloaded data be saved in .dta and .sav in the current directory?
+#'
+#' @details If export is set to \code{TRUE}, the downloaded data is saved as .dta and .sav
+#'  files in the current directory.
 #'
 #' @return \code{voter_profile()} returns a \code{data.frame} with the following variables:
 #'
@@ -33,7 +38,7 @@
 #' df <- voter_profile(2002)
 #' }
 
-voter_profile <- function(year, ascii = FALSE, encoding = "windows-1252"){
+voter_profile <- function(year, ascii = FALSE, encoding = "windows-1252", export = FALSE){
   
   
   # Inputs
@@ -55,7 +60,7 @@ voter_profile <- function(year, ascii = FALSE, encoding = "windows-1252"){
   orig <- getwd()
   setwd(local)
   banco <- Sys.glob("*.txt") %>%
-    read.table(header = F, sep = ";", stringsAsFactors = F, fill = T, fileEncoding =  'windows-1252')
+    read.table(header = F, sep = ";", stringsAsFactors = F, fill = T, fileEncoding = encoding)
   
   unlink(Sys.glob("*.txt"))
   setwd(orig)
@@ -67,6 +72,9 @@ voter_profile <- function(year, ascii = FALSE, encoding = "windows-1252"){
   # Change to ascii
   if(ascii) banco <- to_ascii(banco, encoding)
   
+  # Export
+  if(export) export_data(banco)
+  
   message("Done.\n")
   banco
 }
